/**
 * @file Ce fichier contient les tests des resolvers des users
 * @author ofacklam
*/

import { TestSet } from '../../testData';

export const tests: TestSet = {
    description: "User type resolvers",
    tests: [
        {
            description: "user(uid)",
            query: `
                query {
                    user(uid: "oliver.facklam") {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "uid": "oliver.facklam"
                    }
                }
            }
        },

        {
            description: "user(uid) bad uid",
            query: `
                query {
                    user(uid: "non.existant") {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "user": null
                }
            }
        },

        {
            description: "searchTOL(givenName)",
            query: `
                query {
                    searchTOL(givenName: "Olivér") {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "searchTOL": [
                        {
                            "uid": "oliver.facklam"
                        }
                    ]
                }
            }
        },

        {
            description: "searchTOL(lastName) partial",
            query: `
                query {
                    searchTOL(lastName: "Fack") {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "searchTOL": [
                        {
                            "uid": "hugues.asofa-zeufack"
                        },
                        {
                            "uid": "fabrice.zapfack"
                        },
                        {
                            "uid": "jordan.lekeufack-sopze"
                        },
                        {
                            "uid": "oliver.facklam"
                        }
                    ]
                }
            }
        },

        /*{
            description: "searchTOL(groups) triclassés",
            query: `
                query {
                    searchTOL(groups: ["br", "faerix", "jtx"]) {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "searchTOL": [
                        {
                            "uid": "dubut.2003"
                        },
                        {
                            "uid": "brodard.2004"
                        },
                        {
                            "uid": "le-floch.2004"
                        },
                        {
                            "uid": "rabie.2004"
                        },
                        {
                            "uid": "pierre-etienne.marx"
                        },
                        {
                            "uid": "lauriane.aufrant"
                        },
                        {
                            "uid": "matthias.bry"
                        },
                        {
                            "uid": "julia.chatain"
                        },
                        {
                            "uid": "victor.berger"
                        },
                        {
                            "uid": "augustin.lenormand"
                        },
                        {
                            "uid": "timothee.darcet"
                        }
                    ]
                }
            }
        },*/

        {
            description: "firstName, lastName, nickName",
            query: `
                query {
                    user(uid: "oliver.facklam") {
                        givenName
                        lastName
                        nickname
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "givenName": "Olivér",
                        "lastName": "Facklam",
                        "nickname": null
                    }
                }
            }
        },   
        
        {
            description: "nationality, birthdate",
            query: `
                query {
                    user(uid: "timothee.darcet") {
                        nationality,
                        birthdate
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "nationality": "Française",
                        "birthdate": "1998-05-27"
                    }
                }
            }
        },
    ]
}